@@ -170,13 +170,32 @@ class Layman:
 
     Args:
         installed: путь до installed.xml
+        laymanconf: путь до layman.conf
         makeconf: путь до makeconf
     """
+    layman_package = "app-portage/layman"
+    portage_package = "sys-apps/portage"
 
-    def __init__(self, installed, makeconf):
+    def __init__(self, installed, makeconf, laymanconf=None):
         self.installed = installed
         self.makeconf = makeconf
+        self.laymanconf = laymanconf
 
+    def _add_to_laymanconf(self, rname, rurl, rpath):
+        if not self.laymanconf:
+            return
+        from calculate.lib.cl_template import iniParser
+        ini = iniParser(self.laymanconf)
+        if "rname" in ini.getAllSectionNames():
+            return
+        newrepo = {'auto-sync': 'Yes',
+                   'layman-type': 'git',
+                   'priority': '50',
+                   'sync-uri':rurl,
+                   'sync-type': 'laymansync',
+                   'location': rpath}
+        ini.setVar(rname, newrepo)
+            
     def _add_to_installed(self, rname, rurl):
         """
         Добавить репозиторий в installed.xml
@@ -240,6 +259,15 @@ class Layman:
         Добавить репозиторий в installed.xml и layman/make.conf
         """
         self._add_to_installed(rname, rurl)
+        layman_pkg_info = isPkgInstalled(self.layman_package)
+        portage_pkg_info = isPkgInstalled(self.portage_package)
+        if layman_pkg_info and portage_pkg_info:
+            layman_ver = layman_pkg_info[0]['PV']
+            portage_ver = portage_pkg_info[0]['PV']
+            if (cmpVersion(layman_ver, "2.3") >= 0 and 
+                cmpVersion(portage_ver, "2.2.18") >= 0):
+                self._add_to_laymanconf(rname, rurl, rpath)
+                return True
         self._add_to_makeconf(rpath)
         return True
 
